# Changelog

## 0.1.0 (2024-02-21)


### Features

* add initial version ([8c30f5a](https://github.com/jolars/wikiglot/commit/8c30f5aedb7f0cfc67eb03040b2596dbd482570e))
* **da:** expand inflections for danish ([8c30f5a](https://github.com/jolars/wikiglot/commit/8c30f5aedb7f0cfc67eb03040b2596dbd482570e))
* refactor codebase ([8c30f5a](https://github.com/jolars/wikiglot/commit/8c30f5aedb7f0cfc67eb03040b2596dbd482570e))
* sort pronunciations ([8c30f5a](https://github.com/jolars/wikiglot/commit/8c30f5aedb7f0cfc67eb03040b2596dbd482570e))


### Bug Fixes

* add dependencies ([827d1dd](https://github.com/jolars/wikiglot/commit/827d1dde5e040bb1df4ec22e89377eaccd15b6c0))
* conditionally escape early ([8c30f5a](https://github.com/jolars/wikiglot/commit/8c30f5aedb7f0cfc67eb03040b2596dbd482570e))
* **da:** fix basic inflection checking ([8c30f5a](https://github.com/jolars/wikiglot/commit/8c30f5aedb7f0cfc67eb03040b2596dbd482570e))
* fix various parser issues ([8c30f5a](https://github.com/jolars/wikiglot/commit/8c30f5aedb7f0cfc67eb03040b2596dbd482570e))
* parse "see Thesaurus: &lt;phrase&gt;" gracefully ([8c30f5a](https://github.com/jolars/wikiglot/commit/8c30f5aedb7f0cfc67eb03040b2596dbd482570e))
* parse more carefully ([8c30f5a](https://github.com/jolars/wikiglot/commit/8c30f5aedb7f0cfc67eb03040b2596dbd482570e))
* remove [*] from definitions in english ([8c30f5a](https://github.com/jolars/wikiglot/commit/8c30f5aedb7f0cfc67eb03040b2596dbd482570e))


### Documentation

* add some basic documentation ([53f1001](https://github.com/jolars/wikiglot/commit/53f1001e5bb374999c6ffab40ac264151a90aa57))
* update docs and add changelog ([0c967d4](https://github.com/jolars/wikiglot/commit/0c967d410e0ce593fd14350a755301f26e835535))
* update readme ([9c44066](https://github.com/jolars/wikiglot/commit/9c440662a08c00b578f0e76c1bcc7fe27a780447))
